@@ -1,6 +1,6 @@
 #
 # i-scream pystatgrab
-# http://www.i-scream.org
+# http://www.i-scream.org/pystatgrab/
 # Copyright (C) 2000-2004 i-scream
 #
 # This program is free software; you can redistribute it and/or
@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #
-# $Id: statgrab.py,v 1.6 2004/05/30 16:41:03 tdb Exp $
+# $Id: statgrab.py,v 1.7 2004/08/24 20:43:47 tdb Exp $
 #
 
 import _statgrab
@@ -28,10 +28,14 @@ def sg_drop_privileges():
     return _statgrab.py_sg_drop_privileges()
 def sg_set_error(code, arg=''):
     return _statgrab.py_sg_set_error(code, arg)
+def sg_set_error_with_errno(code, arg=''):
+    return _statgrab.py_sg_set_error_with_errno(code, arg)
 def sg_get_error():
     return _statgrab.py_sg_get_error()
 def sg_get_error_arg():
     return _statgrab.py_sg_get_error_arg()
+def sg_get_error_errno():
+    return _statgrab.py_sg_get_error_errno()
 def sg_str_error(code):
     return _statgrab.py_sg_str_error(code)
 def sg_get_host_info():
